@@ -219,7 +219,7 @@ impl Partition {
         quant: QuantSpec,
     ) -> anyhow::Result<(BitField, PowerPair, PowerPair)> {
         validate_partition_contains_sectors(self, sector_numbers)
-            .map_err(|e| actor_error!(ErrIllegalArgument; "failed fault declaration: {}", e))?;
+            .map_err(|e| actor_error!(USR_ILLEGAL_ARGUMENT; "failed fault declaration: {}", e))?;
 
         let sector_numbers = sector_numbers
             .validate()
@@ -316,7 +316,7 @@ impl Partition {
     ) -> anyhow::Result<()> {
         // Check that the declared sectors are actually assigned to the partition.
         validate_partition_contains_sectors(self, sector_numbers)
-            .map_err(|e| actor_error!(ErrIllegalArgument; "failed fault declaration: {}", e))?;
+            .map_err(|e| actor_error!(USR_ILLEGAL_ARGUMENT; "failed fault declaration: {}", e))?;
 
         let sector_numbers = sector_numbers
             .validate()
@@ -377,7 +377,7 @@ impl Partition {
         quant: QuantSpec,
     ) -> anyhow::Result<Vec<SectorOnChainInfo>> {
         let sector_numbers = sector_numbers.validate().map_err(|e| {
-            actor_error!(ErrIllegalArgument, "failed to validate rescheduled sectors: {}", e)
+            actor_error!(USR_ILLEGAL_ARGUMENT, "failed to validate rescheduled sectors: {}", e)
         })?;
 
         // Ensure these sectors actually belong to this partition.
@@ -490,11 +490,13 @@ impl Partition {
     ) -> anyhow::Result<ExpirationSet> {
         let live_sectors = self.live_sectors();
         let sector_numbers = sector_numbers.validate().map_err(|e| {
-            actor_error!(ErrIllegalArgument, "failed to validate terminating sectors: {}", e)
+            actor_error!(USR_ILLEGAL_ARGUMENT, "failed to validate terminating sectors: {}", e)
         })?;
 
         if !live_sectors.contains_all(sector_numbers) {
-            return Err(actor_error!(ErrIllegalArgument, "can only terminate live sectors").into());
+            return Err(
+                actor_error!(USR_ILLEGAL_ARGUMENT, "can only terminate live sectors").into()
+            );
         }
 
         let sector_infos = sectors.load_sector(sector_numbers)?;
@@ -722,7 +724,7 @@ impl Partition {
         skipped: &mut UnvalidatedBitField,
     ) -> anyhow::Result<(PowerPair, PowerPair, PowerPair, bool)> {
         let skipped = skipped.validate().map_err(|e| {
-            actor_error!(ErrIllegalArgument, "failed to validate skipped sectors: {}", e)
+            actor_error!(USR_ILLEGAL_ARGUMENT, "failed to validate skipped sectors: {}", e)
         })?;
 
         if skipped.is_empty() {
@@ -732,7 +734,7 @@ impl Partition {
         // Check that the declared sectors are actually in the partition.
         if !self.sectors.contains_all(skipped) {
             return Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "skipped faults contains sectors outside partition"
             )
             .into());
@@ -761,7 +763,7 @@ impl Partition {
                 quant,
             )
             .map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to add skipped faults")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to add skipped faults")
             })?;
 
         // Remove faulty recoveries
